@@ -1,9 +1,13 @@
 """Tools that enable operations on graphs where grapsh are represented by an adjacency Mapping.
 
 """
-__version__ = "0.0.2"
 
 from meshed.itools import (
     edges,
     nodes,
 )
+
+from meshed.dag import (
+    DAG,
+    FuncNode,
+)
