@@ -27,19 +27,19 @@ def name_of_obj(o):
     >>> name_of_obj(partial(print, sep=','))
     'print'
     """
-    if hasattr(o, "__name__"):
+    if hasattr(o, '__name__'):
         return o.__name__
-    elif hasattr(o, "__class__"):
+    elif hasattr(o, '__class__'):
         name = name_of_obj(o.__class__)
-        if name == "partial":
-            if hasattr(o, "func"):
+        if name == 'partial':
+            if hasattr(o, 'func'):
                 return name_of_obj(o.func)
         return name
     else:
         return None
 
 
-def incremental_str_maker(str_format="{:03.f}"):
+def incremental_str_maker(str_format='{:03.f}'):
     """Make a function that will produce a (incrementally) new string at every call."""
     i = 0
 
@@ -51,8 +51,8 @@ def incremental_str_maker(str_format="{:03.f}"):
     return mk_next_str
 
 
-lambda_name = incremental_str_maker(str_format="lambda_{:03.0f}")
-unnameable_func_name = incremental_str_maker(str_format="unnameable_func_{:03.0f}")
+lambda_name = incremental_str_maker(str_format='lambda_{:03.0f}')
+unnameable_func_name = incremental_str_maker(str_format='unnameable_func_{:03.0f}')
 
 
 def func_name(func):
@@ -60,7 +60,7 @@ def func_name(func):
     To make one, it calls unamed_func_name which produces incremental names to reduce the chances of clashing"""
     try:
         name = func.__name__
-        if name == "<lambda>":
+        if name == '<lambda>':
             return lambda_name()
         return name
     except AttributeError:
